DEFAULT_POSTGRES_HOST = 'localhost'
DEFAULT_POSTGRES_DATABASE = 'postgres'
DEFAULT_JSON_COLUMN_NAME = 'json'
DEFAULT_ROW_IDENTIFIER = 'id'
DEFAULT_ROW_IDENTIFIER_TYPE = 'SERIAL'
DEFAULT_POSTGRES_PORT = 5432
